/* $Id: bogohist.h,v 1.3 2005/04/04 11:16:19 relson Exp $ */

/*****************************************************************************

NAME:
   histogram.h -- constants and declarations for histogram.c

AUTHOR:
   David Relson <relson@osagesoftware.com>

******************************************************************************/

#ifndef	HISTOGRAM_H
#define	HISTOGRAM_H

#include "paths.h"

extern ex_t histogram(bfpath *bfp);

#endif	/* HISTOGRAM_H */

